@@ -23,6 +23,7 @@ import click
 @click.option('-e', '--eps', type=float, default=1.0, help='Convergence criterium')
 @click.option('-l', '--log_level', default="INFO", help='Log level')
 @click.option('--eigen/--no-eigen', default=False, help='Compute eigenvalues and vectors')
+@click.option('--print_level', type=int, default=1, help='Minimizer print level')
 @click.option('--strategy', type=int, default=0, help='Default strategy')
 @click.option('--fix-cache/--no-fix-cache', default=True, help='Fix StarMomentMorph cache')
 @click.option('--fix-multi/--no-fix-multi', default=True, help='Fix MultiPdf level 2')
@@ -115,6 +116,7 @@ def plot_pulls(**kwargs):
 @click.option('--binned/--unbinned', default=True, help='Binned likelihood')
 @click.option('-e', '--eps', type=float, default=1.0, help='Convergence criterium')
 @click.option('--strategy', type=int, default=0, help='Default minimization strategy')
+@click.option('--print_level', type=int, default=1, help='Minimizer print level')
 @click.option('--fix-cache/--no-fix-cache', default=True, help='Fix StarMomentMorph cache')
 @click.option('--fix-multi/--no-fix-cache',  default=True, help='Fix MultiPdf level 2')
 @click.option('--mpsplit',  default=3, help='MP split mode')
@@ -156,7 +158,7 @@ def likelihood_scan(**kwargs):
 @click.option('-a', '--minimizer_algo', default="Migrad", help='Minimizer algorithm')
 @click.option('-e', '--eps', type=float, default=1.0, help='Convergence criterium')
 @click.option('--strategy', type=int, default=1, help='Default minimization strategy')
-@click.option('--print_level', type=int, default=-1, help='Minimizer print level')
+@click.option('--print_level', type=int, default=1, help='Minimizer print level')
 @click.option('--timer/--no_timer', default=False, help='Enable minimizer timer')
 @click.option('-c', '--num_cpu', type=int, default=1, help='Number of CPUs to use per parameter')
 @click.option('--offset/--no-offset', default=True, help='Offset likelihood')
