@@ -448,7 +448,8 @@ class AsymptoticCLs(AnalysisObject):
         print('Found N * sigma = {} * {}'.format(n, sigma))
         snapshot_0_name = self.nll_maps[asimov_0_nll]['snapshot']
         self.load_snapshot(snapshot_0_name)
-        asimov_data_n = self.model.generate_asimov(self.poi.GetName(), poi_val=n_times_sigma)
+        asimov_data_n = self.model.generate_asimov(self.poi.GetName(), poi_val=n_times_sigma,
+                                                   globs_np_matching=True)
         asimov_n_nll = self.create_nll(asimov_data_n)
         self.load_conditional_snapshot(n_times_sigma, target="globs")
         self.load_conditional_snapshot(n_times_sigma, target="nuis")
@@ -480,9 +481,10 @@ class AsymptoticCLs(AnalysisObject):
         
         # profile NP to mu = 0 if unblinded else no profiling
         poi_profile = None if self.do_blind else 0
-
+        globs_np_matching = not self.do_blind
         asimov_data_0 = self.model.generate_asimov(self.poi.GetName(), poi_val=0,
-                                                   poi_profile=poi_profile, dataset=self.data)
+                                                   poi_profile=poi_profile, dataset=self.data,
+                                                   globs_np_matching=globs_np_matching)
         asimov_0_nll = self.create_nll(asimov_data_0)
         self.summary[0] = {'dataset': asimov_data_0, 'nll': asimov_0_nll}
         self.set_poi_value(0)
