@@ -15,7 +15,9 @@ from matplotlib.backends.backend_pdf import PdfPages
 from quickstats.utils.process_tools import parallel_run
 from quickstats.plots.template import draw_ATLAS_label, format_axis_ticks, parse_transform, draw_hatches, \
                                       draw_sigma_bands, draw_sigma_lines, get_box_dimension, draw_text, centralize_axis
-from quickstats.components.numerics import ceildiv
+from quickstats.components.numerics import ceildiv, pretty_float
+from quickstats.utils.common_utils import json_load
+
 BASE_STYLE = {
     'pull': {
         'marker'     : 'o', 
@@ -158,7 +160,7 @@ class NPRankingPlot:
     @staticmethod
     def _extract_pull_result(file:str, poi:str=None):
         with open(file, 'r') as infile:
-                data = json.load(infile)
+                data = json_load(infile)
         result = {}
         nuis_data = data['nuis']
         result['nuis_label']  = nuis_data['nuisance']
@@ -442,6 +444,8 @@ class NPRankingPlot:
         if extra_text is not None:
             texts += extra_text.split("//")
         if elumi_label:
+            energy = pretty_float(energy)
+            lumi = pretty_float(lumi)
             s = r'$\sqrt{s}$' + ' = {} TeV, {} '.format(energy, lumi) + r'fb$^{-1}$'
             texts.append(s)
         if ranking_label:
